<?php
/**
 * @file
 * Defines the toggl_query class.
 */

/**
 * Builds and executes queries for the Toggl.com REST API.
 *
 * @see http://www.toggl.com/public/api
 */
class toggl_query extends rest_api_query {
  protected $rest_api_schema = 'toggl';

  // Toggl.com authenticates via BasicAuth using the API key as username and "api_token" as password.
  protected $password = 'api_token';

  /**
   * Constructor requires a valid API key and access point URL to initialize.
   *
   * These can be set with Drupal variables instead.  E.g. In settings.php:
   *  @code
   *    $conf['toggl_api_key'] = 'VALUE';
   *  @code
   *
   * @todo Postponed: Support authentication by username & password too.
   *
   * @param $api_key String
   *    The API key to authenticate with Toggl.com via the API.  Defaults to
   *    variable_get('toggl_api_key')
   */
  function __construct($api_token = NULL) {
    $settings = array(
      'access_point' => 'https://www.toggl.com/api/v6',
      'api_key' => $api_token,
      // Set the password again, since setting $this->access_point overwrites
      // $this->password.
      'password' => 'api_token',
    );
    parent::__construct($settings);
  }
}


/**
 * Extends toggl_query class to set the API Token from user profiles.
 */
class toggl_user_token_query extends toggl_query {
  // Make the api_key overridable.
  public $api_key;

  /**
   * Constructor requires a valid API key and access point URL to initialize.
   *
   * These can be set with Drupal variables instead.  E.g. In settings.php:
   * @code
   *  $conf['toggl_api_key'] = 'VALUE';
   * @code
   *
   * @param $user Mixed
   *    Depending on the type;
   *    - NULL (default):  The current user's API token
   *    - Integer:  User ID of the user whose API token should be used.
   *    - Object:  Drupal user object of the user whose API gokdn to use.
   *    - String:  API access key
   */
  function __construct($user = NULL) {
    // Hand off the rest to toggl_query class.
    parent::__construct(get_user_access_key('toggl_api_token', $user));
  }
}
